@@ -2,6 +2,7 @@
 
    Copyright (C) 2007 by Javier Goday <jgoday@gmail.com>
    Copyright (C) 2009 by Dario Massarin <nekkar@libero.it>
+   Copyright (C) 2010 by Matthias Fuchs <mat69@gmx.net>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -21,6 +22,7 @@
 #include <QObject>
 #include <QList>
 
+class KGetKJobAdapter;
 class TransferHandler; 
 class TransferGroupHandler;
 
@@ -34,17 +36,25 @@ public:
     void settingsChanged();
 
 public slots:
-    void slotTransferAdded(TransferHandler * transfer, TransferGroupHandler * group);
-    void slotTransferAboutToBeRemoved(TransferHandler * transfer, TransferGroupHandler * group);
+    void slotTransfersAdded(QList<TransferHandler*> transfers);
+    void slotTransfersAboutToBeRemoved(const QList<TransferHandler*> &transfer);
     void slotTransfersChanged(QMap<TransferHandler *, Transfer::ChangesFlags> transfers);
-    
+
+private slots:
+    void slotRequestStop(KJob *job, TransferHandler *transfer);
+
 private:
     void registerJob(KJob * job, TransferHandler * transfer);
-    void unregisterJob(KJob * job, TransferHandler * transfer);
+    void registerJob(KGetKJobAdapter *job, TransferHandler *transfer);
+    /**
+     * Unregisters job and returns true if it worked
+     */
+    bool unregisterJob(KJob * job, TransferHandler * transfer);
     bool shouldBeShown(TransferHandler * transfer);
     bool existRunningTransfers();
     KGetGlobalJob * globalJob();
 
+private:
     QMap <TransferHandler *, KJob *> m_registeredJobs;
     QList <TransferHandler *> m_invalidTransfers;
     KGetGlobalJob *m_globalJob;
