@@ -1,6 +1,6 @@
 /* This file is part of the KDE project
 
-   Copyright (C) 2007 Lukas Appelhans <l.appelhans@gmx.de>
+   Copyright (C) 2007 - 2010 Lukas Appelhans <l.appelhans@gmx.de>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -15,15 +15,28 @@
 #include "btdatasource.h"
 #include "bttransferhandler.h"
 #include "btdetailswidget.h"
+#include "btjobtracker.h"
 #include "advanceddetails/btadvanceddetailswidget.h"
 
 #include <kdebug.h>
+#include <util/functions.h>
+#include <version.h>
+#include <torrent/job.h>
 
 KGET_EXPORT_PLUGIN(BTTransferFactory)
 
 BTTransferFactory::BTTransferFactory(QObject *parent, const QVariantList &args)
   : TransferFactory(parent, args)
 {
+#if LIBKTORRENT_VERSION >= 0x010100
+    if (!bt::InitLibKTorrent())
+    {
+        kError(5001) << "Failed to initialize libktorrent";
+        KGet::showNotification(0, "error", i18n("Cannot initialize libktorrent. Torrent support might not work."));
+    }
+
+    bt::Job::setJobTracker(new BTJobTracker(this));
+#endif
 }
 
 BTTransferFactory::~BTTransferFactory()
