@@ -43,8 +43,9 @@ class TransferMultiSegKio : public Transfer
          */
         virtual bool setDirectory(const KUrl &newDirectory);
 
-        void init();
-        void deinit();
+        virtual void init();
+        virtual void deinit();
+        virtual void synchronDeinit();
 
         QHash<KUrl, QPair<bool, int> > availableMirrors(const KUrl &file) const;
         void setAvailableMirrors(const KUrl &file, const QHash<KUrl, QPair<bool, int> > &mirrors);
@@ -69,8 +70,6 @@ class TransferMultiSegKio : public Transfer
         void start();
         void stop();
 
-        bool isResumable() const;
-
         void save(const QDomElement &element);
         void load(const QDomElement *e);
         void slotChecksumFound(QString type, QString checksum);
@@ -79,12 +78,9 @@ class TransferMultiSegKio : public Transfer
         void createJob();
 
     private slots:
-        void slotPercent(ulong percent);
-        void slotProcessedSize(KIO::filesize_t processedSize);
-        void slotSpeed(unsigned long bytes_per_second);
-        void slotTotalSize(KIO::filesize_t size);
+        void slotDataSourceFactoryChange(Transfer::ChangesFlags change);
+        void slotUpdateCapabilities();
         void slotSearchUrls(const QList<KUrl> &urls);
-        void slotStatus(Job::Status status);
         void slotRename(const KUrl &oldUrl, const KUrl &newUrl);
         void slotVerified(bool isVerified);
 
