@@ -34,7 +34,8 @@ class TransferMultiSegKioFactory : public TransferFactory
         QWidget * createDetailsWidget( TransferHandler * transfer );
 
         const QList<KAction *> actions(TransferHandler *handler = 0);
-        TransferDataSource * createTransferDataSource(const KUrl &srcUrl);
+        TransferDataSource * createTransferDataSource(const KUrl &srcUrl, const QDomElement &type, QObject *parent);
+        bool isSupported(const KUrl &url) const;
 };
 
 #endif
