@@ -154,8 +154,10 @@ void InfoEventIconLabel::updateIcon()
 {
 	if ( Kopete::InfoEventManager::self()->eventCount() > 0 )
 		setPixmap( SmallIcon( "flag-green" ) );
-	else
+	else {
 		setPixmap( SmallIcon( "flag-black" ) );
+		emit clicked();
+	}
 }
 //END InfoEventIconLabel
 
@@ -262,6 +264,7 @@ KopeteWindow::KopeteWindow ( QWidget *parent )
 	d->statusBarWidget = new KHBox ( statusBar() );
 	d->statusBarWidget->setMargin ( 2 );
 	d->statusBarWidget->setSpacing ( 1 );
+	window()->setAttribute( Qt::WA_AlwaysShowToolTips );
 	statusBar()->addPermanentWidget ( d->statusBarWidget, 0 );
 	QWidget *statusBarMessage = new QWidget ( statusBar() );
 	QHBoxLayout *statusBarMessageLayout = new QHBoxLayout ( statusBarMessage );
@@ -311,14 +314,6 @@ KopeteWindow::KopeteWindow ( QWidget *parent )
 	connect ( Kopete::IdentityManager::self(), SIGNAL ( identityUnregistered ( const Kopete::Identity* ) ),
 	          this, SLOT ( slotIdentityUnregistered ( const Kopete::Identity* ) ) );
 
-	//Connect the appropriate account signals
-	/* Please note that I tried to put this in the slotAllPluginsLoaded() function
-	 * but it seemed to break the account icons in the statusbar --Matt */
-	connect ( Kopete::AccountManager::self(), SIGNAL ( accountRegistered ( Kopete::Account* ) ),
-	          this, SLOT ( slotAccountRegistered ( Kopete::Account* ) ) );
-	connect ( Kopete::AccountManager::self(), SIGNAL ( accountUnregistered ( const Kopete::Account* ) ),
-	          this, SLOT ( slotAccountUnregistered ( const Kopete::Account* ) ) );
-
 	connect ( d->autoHideTimer, SIGNAL ( timeout() ), this, SLOT ( slotAutoHide() ) );
 	connect ( d->contactlist, SIGNAL( visibleContentHeightChanged() ), this, SLOT ( slotStartAutoResizeTimer() ) );
 	connect ( d->autoResizeTimer, SIGNAL ( timeout() ), this, SLOT ( slotUpdateSize() ) );
@@ -339,11 +334,6 @@ KopeteWindow::KopeteWindow ( QWidget *parent )
 	foreach ( Kopete::Identity *i, identityList )
 	slotIdentityRegistered ( i );
 
-	// If some account already loaded, build the status icon
-	QList<Kopete::Account *> accountList = Kopete::AccountManager::self()->accounts();
-	foreach ( Kopete::Account *a, accountList )
-	slotAccountRegistered ( a );
-
 	//install an event filter for the quick search toolbar so we can
 	//catch the hide events
 	toolBar ( "quickSearchBar" )->installEventFilter ( this );
@@ -429,7 +419,7 @@ void KopeteWindow::initActions()
 	Kopete::StatusRootAction* statusAction = new Kopete::StatusRootAction ( d->actionStatusMenu );
 
 	connect ( statusAction, SIGNAL ( changeStatus ( uint, const Kopete::StatusMessage& ) ),
-	          Kopete::AccountManager::self(), SLOT ( setOnlineStatus ( uint, const Kopete::StatusMessage& ) ) );
+	          this, SLOT ( setOnlineStatus ( uint, const Kopete::StatusMessage& ) ) );
 	connect ( statusAction, SIGNAL ( updateMessage ( Kopete::StatusRootAction* ) ),
 	          this, SLOT ( updateStatusMenuMessage ( Kopete::StatusRootAction* ) ) );
 	connect ( statusAction, SIGNAL ( changeMessage ( const Kopete::StatusMessage& ) ),
@@ -665,6 +655,9 @@ void KopeteWindow::slotToggleShowEmptyGroups()
 	Kopete::AppearanceSettings::self()->writeConfig();
 }
 
+static bool compareOnlineStatus(const Kopete::Account *a, const Kopete::Account *b);
+static bool invertedCompareOnlineStatus(const Kopete::Account *a, const Kopete::Account *b);
+
 void KopeteWindow::slotConfigChanged()
 {
 	bool groupContactByGroupModel = qobject_cast<Kopete::UI::ContactListTreeModel*>( d->model );
@@ -727,6 +720,7 @@ void KopeteWindow::slotConfigChanged()
 		else
 		{
 			QList<Kopete::Account *> accountList = Kopete::AccountManager::self()->accounts();
+			qSort(accountList.begin(), accountList.end(), invertedCompareOnlineStatus);
 			foreach ( Kopete::Account *account, accountList )
 			{
 				KopeteAccountStatusBarIcon *sbIcon = new KopeteAccountStatusBarIcon ( account, d->statusBarWidget );
@@ -912,6 +906,20 @@ void KopeteWindow::slotAllPluginsLoaded()
 
 	KConfigGroup cg( KGlobal::config(), "General Options" );
 
+	// If some account already loaded, build the status icon
+	QList<Kopete::Account *> accountList = Kopete::AccountManager::self()->accounts();
+	qSort(accountList.begin(), accountList.end(), invertedCompareOnlineStatus);
+	foreach ( Kopete::Account *a, accountList )
+	slotAccountRegistered ( a );
+
+	//Connect the appropriate account signals
+	/* Please note that I tried to put this in the slotAllPluginsLoaded() function
+	 * but it seemed to break the account icons in the statusbar --Matt */
+	connect ( Kopete::AccountManager::self(), SIGNAL ( accountRegistered ( Kopete::Account* ) ),
+	          this, SLOT ( slotAccountRegistered ( Kopete::Account* ) ) );
+	connect ( Kopete::AccountManager::self(), SIGNAL ( accountUnregistered ( const Kopete::Account* ) ),
+	          this, SLOT ( slotAccountUnregistered ( const Kopete::Account* ) ) );
+
 	if ( d->showIdentityIcons )
 	{
 		QString identityId = cg.readEntry( "ShownIdentityId", Kopete::IdentityManager::self()->defaultIdentity()->id() );
@@ -1037,9 +1045,28 @@ void KopeteWindow::slotIdentityStatusIconChanged ( Kopete::Identity *identity )
 		i->setPixmap ( pm );
 }
 
-bool compareOnlineStatus(const Kopete::Account *a, const Kopete::Account *b)
+static bool compareOnlineStatus(const Kopete::Account *a, const Kopete::Account *b)
 {
-	return (a->myself()->onlineStatus().status() > b->myself()->onlineStatus().status());
+	int c = 0;
+
+	if (a->identity() && b->identity()) {
+		c = QString::localeAwareCompare(a->identity()->label(), b->identity()->label());
+	}
+
+	if (c == 0) {
+		c = a->myself()->onlineStatus().status() - b->myself()->onlineStatus().status();
+
+		if (c == 0) {
+			return (QString::localeAwareCompare(a->protocol()->displayName(), b->protocol()->displayName()) < 0);
+		}
+		return (c > 0);
+	}
+	return (c < 0);
+}
+
+static bool invertedCompareOnlineStatus(const Kopete::Account *a, const Kopete::Account *b)
+{
+	return !compareOnlineStatus(a, b);
 }
 
 void KopeteWindow::makeTrayToolTip()
@@ -1193,6 +1220,7 @@ void KopeteWindow::slotTrayAboutToShowMenu ( KMenu * popup )
 	popup->addTitle ( qApp->windowIcon(), KGlobal::caption() );
 
 	QList<Kopete::Account *> accountList = Kopete::AccountManager::self()->accounts();
+	qSort(accountList.begin(), accountList.end(), invertedCompareOnlineStatus);
 	foreach ( Kopete::Account *account, accountList )
 	{
 		KActionMenu *menu = new KActionMenu ( account->accountId(), account );
@@ -1264,12 +1292,18 @@ void KopeteWindow::slotStartAutoResizeTimer()
 			d->autoResizeTimer->start ( 1000 );
 }
 
+void KopeteWindow::setOnlineStatus( uint category, const Kopete::StatusMessage& statusMessage )
+{
+	Kopete::AccountManager::self()->setOnlineStatus( category, statusMessage, 0, true );
+}
+
 // Iterate each connected account, updating its status message but keeping the
 // same onlinestatus.  Then update Kopete::Away and the UI.
 void KopeteWindow::setStatusMessage ( const Kopete::StatusMessage& statusMessage )
 {
 	bool changed = false;
 	QList<Kopete::Account*> accountList = Kopete::AccountManager::self()->accounts();
+	qSort(accountList.begin(), accountList.end(), invertedCompareOnlineStatus);
 	foreach ( Kopete::Account *account, accountList )
 	{
 		Kopete::Contact *self = account->myself();
