@@ -20,8 +20,8 @@
     *************************************************************************
 */
 
-#ifndef __KOPETECHATSESSION_H__
-#define __KOPETECHATSESSION_H__
+#ifndef KOPETECHATSESSION_H
+#define KOPETECHATSESSION_H
 
 #include <QtCore/QObject>
 
@@ -46,6 +46,7 @@ class Protocol;
 class OnlineStatus;
 class Account;
 class ChatSessionManager;
+class PropertyContainer;
 class MessageHandlerChain;
 class TemporaryKMMCallbackAppendMessageHandler;
 
@@ -121,6 +122,17 @@ public:
 	 */
 	const QString displayName();
 
+	/**
+	* sets lastUrl for current ChatSession
+	*/
+	void setLastUrl( const QString &verylastUrl );
+
+	/**
+	* returns lastUrl for current ChatSession
+	* can be empty
+	*/
+	const QString lastUrl();
+
 	/**
 	 * @brief change the displayname
 	 *
@@ -191,6 +203,31 @@ public:
 	 */
 	bool warnGroupChat() const;
 
+	/**
+	 * finds proper file with lasturls for current
+	 * contact ChatSession->members().first()
+	 * then sets lasturl for current ChatSession
+	 * if there is no file, lasturl will be set to empty string
+	 */
+	QString initLastUrl( const Kopete::Contact* c );
+
+	/**
+	* returns file name where urls for this contact supposed to be
+	*/
+	static QString getUrlsFileName(const Kopete::Contact*);
+
+	/**
+	* prosesses every sent/appended message
+	* looks for urls, if found: sets current lastUrl and save it to proper file
+	*/
+	void urlSearch( const Kopete::Message &msg );
+
+	/**
+	 * finds all urls in the current message (if there are many)
+	 * sorts them as they are in the meassage QStringList[0] - is the earliest
+	 */
+	QStringList findUrls(const Kopete::Message &msg );
+
 signals:
 	/**
 	 * @brief the KMM will be deleted
@@ -234,13 +271,18 @@ signals:
 	/**
 	 * @brief a contact is no longer in this chat
 	 */
-	void contactRemoved( const Kopete::Contact *contact, const QString &reason, Qt::TextFormat format = Qt::PlainText, bool contactRemoved = false );
+	void contactRemoved( const Kopete::Contact *contact, const QString &reason, Qt::TextFormat format = Qt::PlainText, bool suppressNotification = false );
 
 	/**
 	 * @brief a contact in this chat has changed his status
 	 */
 	void onlineStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus & );
 
+	/**
+	 * @brief a contact in this chat has changed his nickname
+	 */
+	void nickNameChanged( Kopete::Contact *, const QString & );
+
 	/**
 	 * @brief The name of the chat is changed
 	 */
@@ -268,6 +310,11 @@ signals:
 	 */
 	void eventNotification( const QString& notificationText);
 
+	/**
+	 * Signals that view for that chat session was activated
+	 */
+	void viewActivated( KopeteView* view );
+
 	/**
 	 * Signals that a message has changed its state.
 	 * The chat window connects to this signal to update the message in chat view.
@@ -405,6 +452,7 @@ private slots:
 	void slotOnlineStatusChanged( Kopete::Contact *c, const Kopete::OnlineStatus &status, const Kopete::OnlineStatus &oldStatus );
 	void slotContactDestroyed( Kopete::Contact *contact );
 	void slotMyselfDestroyed( Kopete::Contact *contact );
+	void slotContactPropertyChanged( Kopete::PropertyContainer * contact, const QString &key, const QVariant &oldValue, const QVariant &newValue );
 
 protected:
 	/**
