@@ -29,6 +29,7 @@
 #include <kmessagebox.h>
 #include <kstandarddirs.h>
 #include <kdeversion.h>
+#include <kapplication.h>
 
 #include "kopetechatsessionmanager.h"
 #include "kopetemetacontact.h"
@@ -68,8 +69,10 @@ StatisticsPlugin::StatisticsPlugin( QObject *parent, const QVariantList &/*args*
 	connect(Kopete::ContactList::self(), SIGNAL(metaContactSelected(bool)),
 		viewMetaContactStatistics, SLOT(setEnabled(bool)));
 	connect(Kopete::ContactList::self(), SIGNAL(metaContactAdded(Kopete::MetaContact*)),
-			this, SLOT(slotMetaContactAdded(Kopete::MetaContact*)));	
-
+	        this, SLOT(slotMetaContactAdded(Kopete::MetaContact*)));
+	connect(Kopete::ContactList::self(), SIGNAL(metaContactRemoved(Kopete::MetaContact*)),
+	        this, SLOT(slotMetaContactRemoved(Kopete::MetaContact*)));
+	
 	setXMLFile("statisticsui.rc");
 
 	/* Initialization reads the database, so it could be a bit time-consuming
@@ -89,24 +92,25 @@ void StatisticsPlugin::slotInitialize()
 	QList<Kopete::MetaContact*> list = Kopete::ContactList::self()->metaContacts();
 	foreach(Kopete::MetaContact *metaContact, list)
 	{
+		kapp->processEvents();
 		slotMetaContactAdded(metaContact);
 	}
 }
 
 StatisticsPlugin::~StatisticsPlugin()
 {
-	map<QString, StatisticsContact*>::iterator it;
-	for (it = statisticsContactMap.begin(); it != statisticsContactMap.end(); ++it)
-	{
-		delete it->second;
-		it->second = 0;
-	}
+	qDeleteAll(statisticsContactMap);
+	statisticsContactMap.clear();
 }
 
 void StatisticsPlugin::slotAboutToReceive(Kopete::Message& m)
 {
-	if (!m.from()->metaContact()->metaContactId().isEmpty() && statisticsContactMap[m.from()->metaContact()->metaContactId()])
-		statisticsContactMap[m.from()->metaContact()->metaContactId()]->newMessageReceived(m);
+	if (!m.from())
+		return;
+
+	StatisticsContact *sc = statisticsContactMap.value(m.from()->metaContact());
+	if (sc)
+		sc->newMessageReceived(m);
 }
 
 void StatisticsPlugin::slotViewCreated(Kopete::ChatSession* session)
@@ -120,48 +124,77 @@ void StatisticsPlugin::slotViewClosed(Kopete::ChatSession* session)
 	foreach(Kopete::Contact *contact, list)
 	{
 		// If this contact is not in other chat sessions
-		if (!contact->manager() && !contact->metaContact()->metaContactId().isEmpty()
-				   && statisticsContactMap[contact->metaContact()->metaContactId()])
-		statisticsContactMap[contact->metaContact()->metaContactId()]->setIsChatWindowOpen(false);
+		if (!contact->manager())
+		{
+			StatisticsContact *sc = statisticsContactMap.value(contact->metaContact());
+			if (sc)
+				sc->setIsChatWindowOpen(false);
+		}
 	}
 }
 
 void StatisticsPlugin::slotViewStatistics()
 {
-	Kopete::MetaContact *m=Kopete::ContactList::self()->selectedMetaContacts().first();
-	
-	kDebug(14315) << "statistics - dialog: " + m->displayName();
-	
-	if (m && !m->metaContactId().isEmpty())
+	Kopete::MetaContact *mc = Kopete::ContactList::self()->selectedMetaContacts().first();
+
+	kDebug(14315) << "statistics - dialog: " + mc->displayName();
+
+	StatisticsContact *sc = statisticsContactMap.value(mc);
+	if (sc)
 	{
-		StatisticsDialog* dialog = new StatisticsDialog(statisticsContactMap[m->metaContactId()], db());
+		StatisticsDialog* dialog = new StatisticsDialog(sc, db());
 		dialog->setObjectName( QLatin1String( "StatisticsDialog" ) );
 		dialog->show();
 	}
 }
 
-void StatisticsPlugin::slotOnlineStatusChanged(Kopete::MetaContact *contact, Kopete::OnlineStatus::StatusType status)
+void StatisticsPlugin::slotOnlineStatusChanged(Kopete::MetaContact *metaContact, Kopete::OnlineStatus::StatusType status)
 {
-	if (statisticsContactMap[contact->metaContactId()])
-			statisticsContactMap[contact->metaContactId()]->onlineStatusChanged(status);
+	StatisticsContact *sc = statisticsContactMap.value(metaContact);
+	if (sc)
+		sc->onlineStatusChanged(status);
 }
 
 void StatisticsPlugin::slotMetaContactAdded(Kopete::MetaContact *mc)
 {
-	connect(mc, SIGNAL(onlineStatusChanged( Kopete::MetaContact *, Kopete::OnlineStatus::StatusType)), this, 		
-					SLOT(slotOnlineStatusChanged(Kopete::MetaContact*, Kopete::OnlineStatus::StatusType)));
-	
-	if (!mc->metaContactId().isEmpty())
-		statisticsContactMap[mc->metaContactId()] = new StatisticsContact(mc, db());
+	connect(mc, SIGNAL(onlineStatusChanged(Kopete::MetaContact *, Kopete::OnlineStatus::StatusType)), this,
+	        SLOT(slotOnlineStatusChanged(Kopete::MetaContact*, Kopete::OnlineStatus::StatusType)));
+
+	statisticsContactMap[mc] = new StatisticsContact(mc, db());
+}
+
+void StatisticsPlugin::slotMetaContactRemoved(Kopete::MetaContact *mc)
+{
+	disconnect(mc, 0, this, 0);
+	StatisticsContact *sc = statisticsContactMap.value(mc);
+	if (sc)
+	{
+		statisticsContactMap.remove(mc);
+		delete sc;
+	}
+}
+
+StatisticsContact* StatisticsPlugin::findStatisticsContact(QString id) const
+{
+	QMapIterator<Kopete::MetaContact*, StatisticsContact*> it(statisticsContactMap);
+	while (it.hasNext())
+	{
+		it.next();
+		if (it.key()->metaContactId() == id)
+			return it.value();
+	}
+
+	return 0;
 }
 
 void StatisticsPlugin::dbusStatisticsDialog(QString id)
 {
 	kDebug(14315) << "statistics - DBus dialog :" << id;
-	
-	if (statisticsContactMap[id])
+
+	StatisticsContact *sc = findStatisticsContact(id);
+	if (sc)
 	{
-		StatisticsDialog* dialog = new StatisticsDialog(statisticsContactMap[id], db());
+		StatisticsDialog* dialog = new StatisticsDialog(sc, db());
 		dialog->setObjectName( QLatin1String("StatisticsDialog") );
 		dialog->show();
 	}	
@@ -207,9 +240,11 @@ bool StatisticsPlugin::dbusWasStatus(QString id, QDateTime dateTime, Kopete::Onl
 {
 	kDebug(14315) << "statistics - DBus wasOnline :" << id;
 	
-	if (dateTime.isValid() && statisticsContactMap[id])
+	if (dateTime.isValid())
 	{
-		return statisticsContactMap[id]->wasStatus(dateTime, status);
+		StatisticsContact *sc = findStatisticsContact(id);
+		if (sc)
+			return sc->wasStatus(dateTime, status);
 	}
 	
 	return false;	
@@ -226,24 +261,53 @@ QString StatisticsPlugin::dbusStatus(QString id, int timeStamp)
 QString StatisticsPlugin::dbusStatus(QString id, QString dateTime)
 {
 	QDateTime dt = QDateTime::fromString(dateTime);
-	
-	if (dt.isValid() && statisticsContactMap[id])
+	if (dt.isValid())
 	{
-		return statisticsContactMap[id]->statusAt(dt);
+		StatisticsContact *sc = findStatisticsContact(id);
+		if (sc)
+			return sc->statusAt(dt);
 	}
-	
+
 	return "";
 }
 
+
 QString StatisticsPlugin::dbusMainStatus(QString id, int timeStamp)
 {
 	QDateTime dt;
 	dt.setTime_t(timeStamp);
-	if (dt.isValid() && statisticsContactMap[id])
+	if (dt.isValid())
 	{
-		return statisticsContactMap[id]->mainStatusDate(dt.date());
+		StatisticsContact *sc = findStatisticsContact(id);
+		if (sc)
+			return sc->mainStatusDate(dt.date());
 	}
 	
 	return "";
 }
+
+void StatisticsPlugin::aboutToUnload()
+{
+	/* Upon exit kopete will set the online status of each metacontact to
+	 * "unknown", causing a storm of synchronous writes to the DB.
+	 * Disconnect the signal and batch a single transaction.
+	 */
+	m_db->transaction();
+
+	QMap<Kopete::MetaContact *, StatisticsContact *>::iterator it;
+	for (it = statisticsContactMap.begin(); it != statisticsContactMap.end(); ++it) {
+		kapp->processEvents();
+		Kopete::MetaContact *mc = it.key();
+		StatisticsContact *sc = it.value();
+
+		disconnect(mc, 0, this, 0);
+		sc->onlineStatusChanged(Kopete::OnlineStatus::Unknown);
+	}
+
+	m_db->commit();
+
+	/* Report ready for unload */
+	emit readyForUnload();
+}
+
 #include "statisticsplugin.moc"
