@@ -1,7 +1,7 @@
 /*
  *            kPPP: A pppd front end for the KDE project
  *
- * $Id: pppstatdlg.cpp 405167 2005-04-12 21:44:21Z porten $
+ * $Id: pppstatdlg.cpp 750800 2007-12-20 07:47:21Z mlaurent $
  *
  *            Copyright (C) 1997 Bernd Johannes Wuebben
  *                   wuebben@math.cornell.edu
@@ -19,23 +19,31 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 
 #include <qlayout.h>
 #include <qpainter.h>
-#include <kwin.h>
+#include <kguiitem.h>
+//Added by qt3to4:
+#include <QPixmap>
+#include <QGridLayout>
+#include <QCloseEvent>
+#include <QEvent>
+#include <QHBoxLayout>
+#include <QVBoxLayout>
+#include <QApplication>
+#include <kwindowsystem.h>
 #include <kiconloader.h>
-#include <kapplication.h>
 #include <klocale.h>
 #include <qlabel.h>
-#include <qframe.h>
-#include <qgroupbox.h>
+#include <q3frame.h>
+#include <q3groupbox.h>
 #include <qlineedit.h>
 #include <qtimer.h>
 #include <kpushbutton.h>
-#include <kstdguiitem.h>
+#include <KStandardGuiItem>
 
 #include "pppdata.h"
 #include "pppstatdlg.h"
@@ -46,23 +54,26 @@ extern PPPData gpppdata;
 
 PPPStatsDlg::PPPStatsDlg(QWidget *parent, const char *name, QWidget *,
 			 PPPStats *st)
-  : QWidget(parent, name, 0),
+  : QWidget(parent),
     stats(st)
 {
   int i;
   max = 1024;
 
-  setCaption(i18n("kppp Statistics"));
-  KWin::setIcons(winId(), kapp->icon(), kapp->miniIcon());
+  setObjectName(name);
 
-  QVBoxLayout *tl = new QVBoxLayout(this, 10);
-  QGridLayout *l1 = new QGridLayout(4, 4);
+  setWindowTitle(i18n("kppp Statistics"));
+  KWindowSystem::setIcons(winId(), qApp->windowIcon().pixmap(IconSize(KIconLoader::Desktop),IconSize(KIconLoader::Desktop)), qApp->windowIcon().pixmap(IconSize(KIconLoader::Small),IconSize(KIconLoader::Small)));
+
+  QVBoxLayout *tl = new QVBoxLayout(this);
+  tl->setSpacing(10);
+  QGridLayout *l1 = new QGridLayout();
   tl->addLayout(l1, 1);
-  box = new QGroupBox(i18n("Statistics"), this);
-  l1->addMultiCellWidget(box, 0, 3, 0, 3);
-  l1->addRowSpacing(0, fontMetrics().lineSpacing() - 10);
+  box = new Q3GroupBox(i18n("Statistics"), this);
+  l1->addWidget(box, 0, 0, 4, 4);
+  l1->addItem(new QSpacerItem(0, fontMetrics().lineSpacing() - 10), 0, 0);
   l1->setRowStretch(1, 1);
-  l1->setColStretch(1, 1);
+  l1->setColumnStretch(1, 1);
 
   // inner part of the grid
   QVBoxLayout *l11 = new QVBoxLayout;
@@ -80,22 +91,22 @@ PPPStatsDlg::PPPStatsDlg(QWidget *parent, const char *name, QWidget *,
   pixmap_l = new QLabel(this);
   pixmap_l->setMinimumSize(big_modem_both_pixmap.size());
   l111->addWidget(pixmap_l, 1);
-  pixmap_l->setAlignment(AlignVCenter|AlignLeft);
+  pixmap_l->setAlignment(Qt::AlignVCenter|Qt::AlignLeft);
 
-  QGridLayout *l1112 = new QGridLayout(3, 2);
+  QGridLayout *l1112 = new QGridLayout();
   l111->addLayout(l1112);
 
   ip_address_label1 = new QLabel(this);
   ip_address_label1->setText(i18n("Local Addr:"));
 
   ip_address_label2 = new IPLineEdit(this);
-  ip_address_label2->setFocusPolicy(QWidget::NoFocus);
+  ip_address_label2->setFocusPolicy(Qt::NoFocus);
 
   ip_address_label3 = new QLabel(this);
   ip_address_label3->setText(i18n("Remote Addr:"));
 
   ip_address_label4 = new IPLineEdit(this);
-  ip_address_label4->setFocusPolicy(QWidget::NoFocus);
+  ip_address_label4->setFocusPolicy(Qt::NoFocus);
 
   l1112->addWidget(ip_address_label1, 0, 0);
   l1112->addWidget(ip_address_label2, 0, 1);
@@ -105,7 +116,7 @@ PPPStatsDlg::PPPStatsDlg(QWidget *parent, const char *name, QWidget *,
   // consumes space on bottom
   l1112->setRowStretch(2, 1);
 
-  QGridLayout *l112 = new QGridLayout(5, 4);
+  QGridLayout *l112 = new QGridLayout();
   l11->addLayout(l112);
   for(i =0 ; i < 5; i++) {
     labela1[i] = new QLabel(this);
@@ -151,8 +162,8 @@ PPPStatsDlg::PPPStatsDlg(QWidget *parent, const char *name, QWidget *,
     l112->addWidget(labelb2[i], i, 3);
   }
 
-  l112->setColStretch(1, 1);
-  l112->setColStretch(3, 1);
+  l112->setColumnStretch(1, 1);
+  l112->setColumnStretch(3, 1);
 
   tl->addSpacing(5);
   QHBoxLayout *l12 = new QHBoxLayout;
@@ -164,19 +175,22 @@ PPPStatsDlg::PPPStatsDlg(QWidget *parent, const char *name, QWidget *,
 
     gpppdata.graphingOptions(dummy, bg, text, in, out);
 
-    graph = new QFrame(this);
+    graph = new QLabel(this);
     graph->setFrameStyle(QFrame::Box | QFrame::Sunken);
-    l1->addMultiCellWidget(graph, 2, 2, 1, 2);
+    l1->addWidget(graph, 2, 1, 1, 2);
     graph->setMinimumWidth(300);
     graph->setFixedHeight(76+4);
-    graph->setBackgroundColor(bg);
+
+    QPalette palette;
+    palette.setColor(graph->backgroundRole(), bg);
+    graph->setPalette(palette);
   }
 
-  cancelbutton = new KPushButton(KStdGuiItem::close(),this, "cancelbutton");
+  cancelbutton = new KPushButton(KStandardGuiItem::close(),this);
   cancelbutton->setFocus();
   connect(cancelbutton, SIGNAL(clicked()), this,SLOT(cancel()));
   cancelbutton->setFixedHeight(cancelbutton->sizeHint().height());
-  cancelbutton->setMinimumWidth(QMAX(cancelbutton->sizeHint().width(), 70));
+  cancelbutton->setMinimumWidth(qMax(cancelbutton->sizeHint().width(), 70));
   l12->addWidget(cancelbutton);
 
   if(gpppdata.graphingEnabled()) {
@@ -246,7 +260,7 @@ void PPPStatsDlg::paintGraph() {
 
   QPixmap pm(graph->width() - 4, graph->height() - 4);
   QPainter p;
-  pm.fill(graph->backgroundColor());
+  pm.fill(graph->palette().color(graph->backgroundRole()));
   p.begin(&pm);
 
   int x;
@@ -289,14 +303,14 @@ void PPPStatsDlg::paintGraph() {
   p.setFont(QFont(KGlobalSettings::fixedFont().family(), 8));
 
   QRect r;
-  QString s = i18n("%1 (max. %2) kb/sec")
-		.arg(KGlobal::locale()->formatNumber((float)last_max / 1024.0, 1))
-		.arg(KGlobal::locale()->formatNumber((float)max / 1024.0, 1));
-  p.drawText(0, 0, pm.width(), 2*8, AlignRight|AlignVCenter, s, -1, &r);
+  QString s = i18n("%1 (max. %2) kb/sec",
+		 KGlobal::locale()->formatNumber((float)last_max / 1024.0, 1),
+		 KGlobal::locale()->formatNumber((float)max / 1024.0, 1));
+  p.drawText(0, 0, pm.width(), 2*8, Qt::AlignRight|Qt::AlignVCenter, s, &r);
   p.drawLine(0, 8, r.left() - 8, 8);
 
   p.end();
-  bitBlt(graph, 2, 2, &pm, 0, 0, pm.width(), pm.height(), CopyROP);
+  graph->setPixmap(pm);
 }
 
 void PPPStatsDlg::updateGraph() {
@@ -314,16 +328,7 @@ void PPPStatsDlg::updateGraph() {
   paintGraph();
 }
 
-
-void PPPStatsDlg::paintEvent (QPaintEvent *) {
-  paintIcon(PPPStats::BytesNone); // correct ?
-  if(gpppdata.graphingEnabled())
-    paintGraph();
-}
-
-
 void PPPStatsDlg::paintIcon(int status) {
-
   const QPixmap *pixmap;
 
   switch(status)
@@ -343,7 +348,7 @@ void PPPStatsDlg::paintIcon(int status) {
       break;
     }
 
-  bitBlt(pixmap_l, 0, 0, pixmap);
+  pixmap_l->setPixmap(*pixmap);
 
   update_data();
 }
@@ -421,7 +426,7 @@ void PPPStatsDlg::update_data() {
 
 
 void PPPStatsDlg::toCurrentDesktop() {
-  KWin::setOnDesktop(winId(), KWin::currentDesktop());
+  KWindowSystem::setOnDesktop(winId(), KWindowSystem::currentDesktop());
 }
 
 #include "pppstatdlg.moc"
